@@ -47,6 +47,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         isInPortait(false),
         isResumePlayback(false),
         isMainToolbarVisible(false),
+        isSeekSliderShown(true),
         fileListWidgetItemFileToDelete(QString())
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -58,7 +59,13 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     this->ui->mainToolBar2->hide();
 
 
-
+    if(SymfonieDb::getInstance()->getSetting("is_seekSlider_visible", QVariant(0)).toInt() == 0){
+        this->isSeekSliderShown = false;
+        this->ui->sliderPanel->hide();
+    }else{
+        this->isSeekSliderShown = true;
+        this->ui->sliderPanel->show();
+    }
 
 
     //set up menus
@@ -247,7 +254,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     QFileInfo info = QFileInfo(lastPlayedDir);
     if(info.exists()){
-        if(SymfonieDb::getInstance()->getSetting("is_auto_resume_playback") != 0){
+        if(SymfonieDb::getInstance()->getSetting("is_auto_resume_playback").toInt() != 0){
             this->isResumePlayback = true;
         }else{
             this->isResumePlayback = false;
@@ -715,8 +722,8 @@ void MainWindow::saveState(){
     // qDebug() << "curent time: "<<this->getPlayer()->getMediaObject()->currentTime();
 
 
-    SymfonieDb::getInstance()->saveSetting("is_seekSlider_visible", QVariant(this->ui->subToolBar->isVisible() ? 1:0));
-    //qDebug() << "is_seekSlider_visible" << SymfonieDb::getInstance()->getSetting("is_seekSlider_visible");
+    SymfonieDb::getInstance()->saveSetting("is_seekSlider_visible", QVariant(this->isSeekSliderShown ? 1:0));
+    qDebug() << "is_seekSlider_visible" << this->isSeekSliderShown;
 
     SymfonieDb::getInstance()->saveSetting("orientation_mode", QVariant(this->currentOrientationMode));
 
@@ -835,12 +842,12 @@ void MainWindow::goHomeSlot(){
 void MainWindow::showInfoWindowSlot(){
     if(this->ui->sliderPanel->isVisible()){
         this->ui->sliderPanel->hide();
-
         this->showInfoWindowAction->setChecked(false);
+        this->isSeekSliderShown = false;
     }else{
         this->ui->sliderPanel->show();
-
         this->showInfoWindowAction->setChecked(true);
+        this->isSeekSliderShown = true;
     }
 
     this->setActionToggleState();
